@@ -1,5 +1,5 @@
 import functools
-from typing import Iterable, Sized, Collection, Callable, Tuple
+from typing import Iterable, Sized, Collection, Callable, Tuple, Any
 from typing import Union, Optional, overload
 
 from labml.internal.monitor import monitor_singleton as _internal
@@ -15,6 +15,8 @@ def func(name, *,
          is_partial: bool = False,
          is_new_line: bool = True,
          is_children_silent: bool = False,
+         is_track: bool = False,
+         is_not_in_loop: bool = False,
          total_steps: float = 1.0):
     """
     This is similar to :func:`section` but can be used as a decorator.
@@ -30,6 +32,8 @@ def func(name, *,
         is_new_line (bool, optional): Whether to print a new line. Defaults to ``True``.
         is_children_silent (bool, optional): Whether to make child sections silent.
             Defaults to ``True``.
+        is_track (bool, optional): Whether to track the time.
+            Defaults to ``False``.
         total_steps (float, optional): Total number of steps. This is used to measure progress when
             :func:`progress` gets called. Defaults to ``1``.
     """
@@ -43,6 +47,8 @@ def func(name, *,
                          is_partial=is_partial,
                          is_new_line=is_new_line,
                          is_children_silent=is_children_silent,
+                         is_track=is_track,
+                         is_not_in_loop=is_not_in_loop,
                          total_steps=total_steps):
                 return f(*args, **kwargs)
 
@@ -56,6 +62,8 @@ def iterate(name, iterable: Union[Iterable, Sized, int],
             is_silent: bool = False,
             is_children_silent: bool = False,
             is_timed: bool = True,
+            is_track: bool = False,
+            is_not_in_loop: bool = False,
             context=None):
     """
     This creates a monitored iterator.
@@ -71,12 +79,16 @@ def iterate(name, iterable: Union[Iterable, Sized, int],
         is_timed (bool, optional): Whether to measure time. Default to ``True``.
         is_children_silent (bool, optional): Whether to make child sections silent.
             Defaults to ``True``.
+        is_track (bool, optional): Whether to track the time.
+            Defaults to ``False``.
         context (optional): Reference to another section that will be used for monitoring the iteration.
     """
     return _internal().iterate(name, iterable, total_steps,
                                is_silent=is_silent,
                                is_children_silent=is_children_silent,
                                is_timed=is_timed,
+                               is_track=is_track,
+                               is_not_in_loop=is_not_in_loop,
                                section=context)
 
 
@@ -84,6 +96,8 @@ def enum(name, iterable: Sized, *,
          is_silent: bool = False,
          is_children_silent: bool = False,
          is_timed: bool = True,
+         is_track: bool = False,
+         is_not_in_loop: bool = False,
          context=None):
     """
     This creates a monitored enumerator.
@@ -97,12 +111,16 @@ def enum(name, iterable: Sized, *,
         is_timed (bool, optional): Whether to measure time. Default to ``True``.
         is_children_silent (bool, optional): Whether to make child sections silent.
             Defaults to ``True``.
+        is_track (bool, optional): Whether to track the time.
+            Defaults to ``False``.
         context (optional): Reference to another section that will be used for monitoring the iteration.
     """
     return _internal().enum(name, iterable,
                             is_silent=is_silent,
                             is_children_silent=is_children_silent,
                             is_timed=is_timed,
+                            is_track=is_track,
+                            is_not_in_loop=is_not_in_loop,
                             section=context)
 
 
@@ -112,6 +130,8 @@ def section(name, *,
             is_partial: bool = False,
             is_new_line: bool = True,
             is_children_silent: bool = False,
+            is_track: bool = False,
+            is_not_in_loop: bool = False,
             total_steps: float = 1.0):
     """
     This creates a monitored ``with`` block.
@@ -127,6 +147,8 @@ def section(name, *,
         is_new_line (bool, optional): Whether to print a new line. Defaults to ``True``.
         is_children_silent (bool, optional): Whether to make child sections silent.
             Defaults to ``True``.
+        is_track (bool, optional): Whether to track the time.
+            Defaults to ``False``.
         total_steps (float, optional): Total number of steps. This is used to measure progress when
             :func:`progress` gets called. Defaults to ``1``.
     """
@@ -135,6 +157,8 @@ def section(name, *,
                                is_partial=is_partial,
                                total_steps=total_steps,
                                is_new_line=is_new_line,
+                               is_track=is_track,
+                               is_not_in_loop=is_not_in_loop,
                                is_children_silent=is_children_silent)
 
 
@@ -210,25 +234,65 @@ def loop(iterator_: Union[Collection, range, int], *,
                                 is_print_iteration_time=is_print_iteration_time)
 
 
-def mix(total_iterations, *iterators: Tuple[str, Sized],
+@overload
+def mix(*iterators: Tuple[Union[str, Callable[[Any], None]], Union[Sized, int]],
+        is_monit: bool = True):
+    ...
+
+
+@overload
+def mix(total_iterations: int, *iterators: Tuple[Union[str, Callable[[Any], None]], Union[Sized, int]],
+        is_monit: bool = True):
+    ...
+
+
+def mix(*args,
         is_monit: bool = True):
     """
-    Mix a set of iterators.
+    This has two overloads
+
+    .. function:: mix(*iterators: Tuple[Union[str, Callable[[Any], None]], Union[Sized, int]], is_monit: bool = True)
+        :noindex:
+
+    .. function:: mix(total_iterations: int, *iterators: Tuple[Union[str, Callable[[Any], None]], Union[Sized, int]], is_monit: bool = True):
+        :noindex:
 
     This will iterate through a list of iterators while mixing among them.
-    This is useful when you want to mix training and validation steps within an epoch.
-    It gives a tuple of iterator name and the element as you iterate.
+    This is useful, for instance, when you want to mix training, validation, sampling steps within an epoch.
+
+    You can give it tuples of iterator names and iterators.
+    It will yield the names along with the iterator values.
+
+    If you pass a function instead of a name it will call that function with the iterator value, instead of
+    yielding it.
 
     Arguments:
         total_iterations (Union[Collection, range, int]): The number of times to mix
-        iterators (Tuple[str, Sized]): Are iterators and their names
-        is_monit (bool, optional): Whether to monitor the iteration
+        iterators (Tuple[Union[str, Callable[[Any], None]], Union[Sized, int]]): Are iterators and their names or callback function
+        is_monit (bool, optional): Whether to monitor the iterations, when inside :func:`loop`. Default to ``True``.
     """
+
+    total_iterations = None
+    iterators = []
+    for arg in args:
+        if isinstance(arg, tuple):
+            r, it = arg
+            if isinstance(it, int):
+                it = range(it)
+            iterators.append((r, it))
+        elif isinstance(arg, int):
+            total_iterations = arg
+        else:
+            raise ValueError(f'Unknown argument type: {type(arg)}, {arg}')
+
+    if total_iterations is None:
+        total_iterations = max(len(iterator[1]) for iterator in iterators)
+
     return _internal().mix(total_iterations, list(iterators), is_monit=is_monit)
 
 
 def finish_loop() -> None:
     """
-    Finish the loop and flush all the loop related montoring stats.
+    Finish the loop and flush all the loop related monitoring stats.
     """
     _internal().finish_loop()
