@@ -1,4 +1,4 @@
-import os
+import os, os.path
 from  pathlib import Path
 from typing import Set, List
 
@@ -14,16 +14,18 @@ def get_caller_file(ignore_callers: Set[str] = None) -> str:
 
     for f in frames:
         module_path = Path(f.filename)
-        if str(module_path).startswith(str(lab_src) + '/'):
+        if str(module_path).startswith(os.path.join(lab_src, '')):
+            continue
+        if '/labml_helpers/' in str(module_path):
             continue
         if str(module_path) in ignore_callers:
             continue
-        if not module_path.exists():
-            break
         if str(module_path).startswith('<stdin'):
             break
         if str(module_path).startswith('<ipython'):
             break
+        if not module_path.exists():
+            break
         if str(module_path.absolute()).find('/dist-packages/') != -1:
             continue
         return str(module_path)
